@@ -19,35 +19,32 @@ jags <- function (data, inits, parameters.to.save, model.file = "model.bug",
     inTempDir <- TRUE
   }
   
-  if (!(length(data) == 1 && is.vector(data) && is.character(data) && 
-        (regexpr("\\.txt$", data) > 0))) {
-  data.list <- lapply(as.list(data), get, pos = parent.frame(1))
-  names(data.list) <- as.list(data)
-  }
-  else {
-    if (inTempDir && all(basename(data) == data)) 
-      try(file.copy(file.path(savedWD, data), data, overwrite = TRUE))
-    if (!file.exists(data)) 
-      stop("File", data, "does not exist.")
+  if(is.list(data)){
     data.list <- data
+    lapply(data.list, dump, append=TRUE, file="jagsdata.txt",
+       envir=parent.frame(1))  
+  }
+  else{
+    if (!(length(data) == 1 && is.vector(data) && is.character(data) && 
+          (regexpr("\\.txt$", data) > 0))) {
+      data.list <- lapply(as.list(data), get, pos = parent.frame(1))
+      names(data.list) <- as.list(data)
+    }
+    else {
+      if (inTempDir && all(basename(data) == data)) {
+        try(file.copy(file.path(savedWD, data), data, overwrite = TRUE))
+      }
+      if (!file.exists(data)) {
+        stop("File", data, "does not exist.")
+      }
+      data.list <- data
+    }
+  lapply(names(data.list), dump, append=TRUE, file="jagsdata.txt",
+       envir=parent.frame(1))
   }
 
   
-  #data.list <- lapply(as.list(data), get, pos = parent.frame(2))
- # data.list <- lapply(as.list(data), get, pos = parent.frame(1))
-#  names(data.list) <- as.list(data)
-#  lapply(names(data.list), dump, append=TRUE, file="jagsdata.txt",
-#      envir=parent.frame(1))
-
-#  if (all(sapply(data,class))=="character") {
-#     data.list <- lapply(as.list(data), get, pos = parent.frame(1))
-#     names(data.list) <- as.list(data)
-#  } 
-#  else {
-#    data.list <- data
-#  }
-   lapply(names(data.list), dump, append=TRUE, file="jagsdata.txt",
-       envir=parent.frame(1))    
+    
 
   data <- read.jagsdata("jagsdata.txt")
   file.remove("jagsdata.txt")              
